// Copyright 2018-2023 the Deno authors. All rights reserved. MIT license.
/** Functions for specific common tasks around collection types like `Array` and
 * `Record`. This module is heavily inspired by `kotlin`s stdlib.
 *
 * - All provided functions are **pure**, which also means that they do **not
 *   mutate** your inputs, **returning a new value** instead.
 * - All functions are importable on their own by referencing their snake_case
 *   named file (e.g. `collections/sort_by.ts`)
 *
 * This module re-exports several modules, and importing this module directly
 * will likely include a lot of code that you might not use.
 *
 * Consider importing the function directly. For example to import
 * {@linkcode groupBy} import the module using the snake cased version of the
 * module:
 *
 * ```ts
 * import { groupBy } from "https://deno.land/std@$STD_VERSION/collections/group_by.ts";
 * ```
 *
 * @module
 */
// Not sure what's causing this warning? Run `deno info <entry-point-path>` to
// analyze the module graph. It's not recommended to import directly from
// mod.ts here because it adds a lot of bloat.
console.warn("%c[WARN] deno_std: prefer importing collections/<function_name_in_snake_case>.ts " +
    "instead of collections/mod.ts", "color: yellow;");
export * from "./aggregate_groups.js";
export * from "./associate_by.js";
export * from "./associate_with.js";
export * from "./chunk.js";
export * from "./deep_merge.js";
export * from "./distinct.js";
export * from "./distinct_by.js";
export * from "./drop_while.js";
export * from "./filter_entries.js";
export * from "./filter_keys.js";
export * from "./filter_values.js";
export * from "./group_by.js";
export * from "./intersect.js";
export * from "./map_entries.js";
export * from "./map_keys.js";
export * from "./map_not_nullish.js";
export * from "./map_values.js";
export * from "./partition.js";
export * from "./permutations.js";
export * from "./find_single.js";
export * from "./sliding_windows.js";
export * from "./sum_of.js";
export * from "./max_by.js";
export * from "./max_of.js";
export * from "./min_by.js";
export * from "./min_of.js";
export * from "./sort_by.js";
export * from "./union.js";
export * from "./without_all.js";
export * from "./unzip.js";
export * from "./zip.js";
export * from "./join_to_string.js";
export * from "./max_with.js";
export * from "./min_with.js";
export * from "./includes_value.js";
export * from "./take_last_while.js";
export * from "./take_while.js";
export * from "./first_not_nullish_of.js";
export * from "./drop_last_while.js";
export * from "./reduce_groups.js";
export * from "./sample.js";
export * from "./running_reduce.js";
export * from "./binary_heap.js";
