"use strict";
// Copyright 2018-2023 the Deno authors. All rights reserved. MIT license.
// This module is browser compatible.
Object.defineProperty(exports, "__esModule", { value: true });
exports.intersect = void 0;
const _utils_js_1 = require("./_utils.js");
/**
 * Returns all distinct elements that appear at least once in each of the given
 * arrays.
 *
 * @example
 * ```ts
 * import { intersect } from "https://deno.land/std@$STD_VERSION/collections/intersect.ts";
 * import { assertEquals } from "https://deno.land/std@$STD_VERSION/testing/asserts.ts";
 *
 * const lisaInterests = ["Cooking", "Music", "Hiking"];
 * const kimInterests = ["Music", "Tennis", "Cooking"];
 * const commonInterests = intersect(lisaInterests, kimInterests);
 *
 * assertEquals(commonInterests, ["Cooking", "Music"]);
 * ```
 */
function intersect(...arrays) {
    const [originalHead, ...tail] = arrays;
    const head = [...new Set(originalHead)];
    const tailSets = tail.map((it) => new Set(it));
    for (const set of tailSets) {
        (0, _utils_js_1.filterInPlace)(head, (it) => set.has(it));
        if (head.length === 0)
            return head;
    }
    return head;
}
exports.intersect = intersect;
