"use strict";
// Copyright 2018-2023 the Deno authors. All rights reserved. MIT license.
// This module is browser compatible.
Object.defineProperty(exports, "__esModule", { value: true });
exports.takeWhile = void 0;
/**
 * Returns all elements in the given collection until the first element that
 * does not match the given predicate.
 *
 * @example
 * ```ts
 * import { takeWhile } from "https://deno.land/std@$STD_VERSION/collections/take_while.ts";
 * import { assertEquals } from "https://deno.land/std@$STD_VERSION/testing/asserts.ts";
 *
 * const arr = [1, 2, 3, 4, 5, 6];
 *
 * assertEquals(
 *   takeWhile(arr, (i) => i !== 4),
 *   [1, 2, 3],
 * );
 * ```
 */
function takeWhile(array, predicate) {
    let offset = 0;
    const length = array.length;
    while (length > offset && predicate(array[offset])) {
        offset++;
    }
    return array.slice(0, offset);
}
exports.takeWhile = takeWhile;
