"use strict";
// Copyright 2018-2023 the Deno authors. All rights reserved. MIT license.
// This module is browser compatible.
Object.defineProperty(exports, "__esModule", { value: true });
exports.zip = void 0;
/**
 * Builds N-tuples of elements from the given N arrays with matching indices,
 * stopping when the smallest array's end is reached.
 *
 * @example
 * ```ts
 * import { zip } from "https://deno.land/std@$STD_VERSION/collections/zip.ts";
 * import { assertEquals } from "https://deno.land/std@$STD_VERSION/testing/asserts.ts";
 *
 * const numbers = [1, 2, 3, 4];
 * const letters = ["a", "b", "c", "d"];
 * const pairs = zip(numbers, letters);
 *
 * assertEquals(
 *   pairs,
 *   [
 *     [1, "a"],
 *     [2, "b"],
 *     [3, "c"],
 *     [4, "d"],
 *   ],
 * );
 * ```
 */
const min_of_js_1 = require("./min_of.js");
function zip(...arrays) {
    const minLength = (0, min_of_js_1.minOf)(arrays, (it) => it.length) ?? 0;
    const ret = new Array(minLength);
    for (let i = 0; i < minLength; i += 1) {
        const arr = arrays.map((it) => it[i]);
        ret[i] = arr;
    }
    return ret;
}
exports.zip = zip;
