/**
 * Returns the first element that is the largest value of the given function or
 * undefined if there are no elements.
 *
 * @example
 * ```ts
 * import { maxBy } from "https://deno.land/std@$STD_VERSION/collections/max_by.ts";
 * import { assertEquals } from "https://deno.land/std@$STD_VERSION/testing/asserts.ts";
 *
 * const people = [
 *   { name: "Anna", age: 34 },
 *   { name: "Kim", age: 42 },
 *   { name: "John", age: 23 },
 * ];
 *
 * const personWithMaxAge = maxBy(people, (i) => i.age);
 *
 * assertEquals(personWithMaxAge, { name: "Kim", age: 42 });
 * ```
 */
export declare function maxBy<T>(array: readonly T[], selector: (el: T) => number): T | undefined;
export declare function maxBy<T>(array: readonly T[], selector: (el: T) => string): T | undefined;
export declare function maxBy<T>(array: readonly T[], selector: (el: T) => bigint): T | undefined;
export declare function maxBy<T>(array: readonly T[], selector: (el: T) => Date): T | undefined;
