/**
 * Returns the first element that is the smallest value of the given function or
 * undefined if there are no elements
 *
 * @example
 * ```ts
 * import { minBy } from "https://deno.land/std@$STD_VERSION/collections/min_by.ts";
 * import { assertEquals } from "https://deno.land/std@$STD_VERSION/testing/asserts.ts";
 *
 * const people = [
 *   { name: "Anna", age: 34 },
 *   { name: "Kim", age: 42 },
 *   { name: "John", age: 23 },
 * ];
 *
 * const personWithMinAge = minBy(people, (i) => i.age);
 *
 * assertEquals(personWithMinAge, { name: "John", age: 23 });
 * ```
 */
export declare function minBy<T>(array: readonly T[], selector: (el: T) => number): T | undefined;
export declare function minBy<T>(array: readonly T[], selector: (el: T) => string): T | undefined;
export declare function minBy<T>(array: readonly T[], selector: (el: T) => bigint): T | undefined;
export declare function minBy<T>(array: readonly T[], selector: (el: T) => Date): T | undefined;
