/**
 * Returns all elements in the given collection, sorted by their result using
 * the given selector. The selector function is called only once for each
 * element.
 *
 * @example
 * ```ts
 * import { sortBy } from "https://deno.land/std@$STD_VERSION/collections/sort_by.ts";
 * import { assertEquals } from "https://deno.land/std@$STD_VERSION/testing/asserts.ts";
 *
 * const people = [
 *   { name: "Anna", age: 34 },
 *   { name: "Kim", age: 42 },
 *   { name: "John", age: 23 },
 * ];
 * const sortedByAge = sortBy(people, (it) => it.age);
 *
 * assertEquals(sortedByAge, [
 *   { name: "John", age: 23 },
 *   { name: "Anna", age: 34 },
 *   { name: "Kim", age: 42 },
 * ]);
 * ```
 */
export declare function sortBy<T>(array: readonly T[], selector: (el: T) => number): T[];
export declare function sortBy<T>(array: readonly T[], selector: (el: T) => string): T[];
export declare function sortBy<T>(array: readonly T[], selector: (el: T) => bigint): T[];
export declare function sortBy<T>(array: readonly T[], selector: (el: T) => Date): T[];
